#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_CHEBVAND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_CHEBVAND_HPP_INCLUDED

#include <nt2/gallery/include/functions/scalar/chebvand.hpp>

#endif
